Jazz-CDs, -DVDs und -Blu-rays – jpc.de
Description: In unserem Onlineshop finden Sie eine umfassende Auswahl an Jazz-CDs, -DVD und -Blu-rays. Und natürlich auch ein großes Angebot für Vinyl-Fans.

Anmelden Konto anlegen

Jazz
ECM – Über 130 reduzierte Preise

Jazz
Weather Report: The Legendary Live Tapes 1978-1981

Jazz
Roger Cicero: Cicero Sings Sinatra - Live in Hamburg

Jazz
Solveig Slettahjell & Knut Reiersrud: Trail Of Souls

1. ECM – Über 130 reduzierte Preise

2. Weather Report: The Legendary Live Tapes 1978-1981

3. Roger Cicero: Cicero Sings Sinatra - Live in Hamburg

4. Solveig Slettahjell & Knut Reiersrud: Trail Of Souls

## Empfehlungen der Jazz-Redaktion

### Jazz-Neuheit der Woche: Solveig Slettahjell & Knut Reiersrud – Trail Of Souls

Mit »Trail Of Souls« erscheint das erste gemeinsame Studioalbum von Solveig Slettahjell und Knut Reiersrud. Am 11. März 2014 gaben die Jazzsängerin und der Bluesgitarrist und -sänger aus Norwegen zusammen mit dem ebenfalls norwegischen Jazztrio In the Country, bestehend a…

CD
EUR 15,99*
Ebenso erhältlich:

- Solveig Slettahjell & Knut Reiersrud: Trail Of Souls, EUR 19,99*

### Roger Cicero: Cicero Sings Sinatra - Live in Hamburg

Am 12. Dezember 2015 wäre er 100 Jahre alt geworden: Swing- und Jazzlegende Frank Sinatra. Sage und schreibe 60 Jahre dauerte seine Karriere, die ihn zu einem der bekanntesten Crooner und gleichzeitig einem der erfolgreichsten Sänger, Sch…

CD
EUR 14,99*
Ebenso erhältlich:

- Roger Cicero: Cicero Sings Sinatra - Live in Hamburg, EUR 17,99*
- » Mehr

### Florian Weber – Criss Cross (Exploring Monk And Bill Evans)

Auf Criss Cross – Exploring the Music of Monk and Bill Evans stellt Florian Weber eine andere Version eines Trios vor, diesmal ohne Bassisten. In dieser Hommage an die beiden Musiker die ihn wohl am meisten beeinflussten, stehen ihm zwei …

CD
EUR 15,99*

### Peter Herbolzheimer: Hip Walk - The Complete Polydor Recordings

Wenn es um brandheißen, fetten Bigband-Jazz mit viel Soul, Jazzrock- und Fusion-Einflüssen ging, war Peter Herbolzheimer seit den Siebziger Jahren erste Wahl. Im Andenken an die 2010 gestorbene Jazzlegende versammelt die 4-CD-Box "Hip Wal…

4 CDs
EUR 26,99*

### John Coltrane – A Love Supreme: The Complete Masters (Super Deluxe)

Zum 50-jährigen Jubiläum von John Coltranes legendärem Album »A Love Supreme« erscheint 2015 mit »A Love Supreme: The Complete Masters« eine Neuauflage der Extraklasse: diese Sammlung enthält alles, was während der zweitägigen Aufnahmen d…

3 CDs
EUR 19,99*
Ebenso erhältlich:

- John Coltrane (1926-1967): A Love Supreme: The Complete Masters, EUR 17,99*

### Scott DuBois – Winter Light

Der 37 Jahre alte US-amerikanische Jazzgitarrist und Komponist Scott DuBois ist einer der wichtigen jungen Protagonisten der New Yorker Jazzszene. Die New York Times schreibt: »DuBois Musik schlägt Wellen. Erzählerisch und von melodischer Sensibilität. Überzeugende Kompositi…

CD
EUR 15,99*
Ebenso erhältlich:

- Scott DuBois (geb. 1978): Winter Light, EUR 24,99*

### Tipps aus der Redaktion

Seien wir ehrlich. Nicht jeder, der »Köln Big Band« hört, denkt sofort an Michael Villmow’s KBB. Bei einer »Cologne Big Band« dürfte mit ziemlicher Sicherheit der Klangkörper der WDR Big Band eher gemeint sein. Viele Städte in...

2 CDs
EUR 21,99*
Ebenso erhältlich:

- Christian Gruber-Ruesz: Instant Asia, EUR 17,99*
- » Mehr

Trilok Gurtu: Crazy Saints: Live Kito, Bremen-Vegesack, 29.11.1993

Günther Fischer: Live In Weimar

Sony Music Nice Price – Jazz

## Jazz-Sonderpreise

- Angebote
- CD-Neuheiten zum Sonderpreis

Sonderangebote Jazz, sortiert nach Verkaufsrang 1 / 2

-44%

###
Keith Jarrett (geb. 1945)
Jasmine

EUR 17,99**
CD
EUR 9,99*

###
Michael Wollny (geb. 1978)
Weltentraum

CD
EUR 10,99*
-46%

###
Gregory Porter (geb. 1971)
Be Good

EUR 14,99**
CD
EUR 7,99*
-41%

###
Keith Jarrett (geb. 1945)
The Köln Concert

EUR 16,99**
CD
EUR 9,99*
-56%

###
Abdullah Ibrahim (Dollar Brand) (geb. 1934)
The Song Is My Story (CD + DVD)

EUR 22,99**
CD, DVD
EUR 9,99*
-44%

###
Anouar Brahem (geb. 1957)
Astrakan Cafe

EUR 17,99**
CD
EUR 9,99*

###
Keith Jarrett & Charlie Haden
Last Dance

CD
EUR 9,99*
-21%

###
Miles Davis (1926-1991)
Kind Of Blue (180g)

EUR 18,99**
LP
EUR 14,99*
-44%

###
Marcin Wasilewski (geb. 1975)
Faithful

EUR 17,99**
CD
EUR 9,99*
-44%

###
Anouar Brahem (geb. 1957)
Le Pas Du Chat Noir

EUR 17,99**
CD
EUR 9,99*
Alle Jazz-Sonderangebote

## Charts

Die aktuellen Jazz-Charts

1. 1
   Keith Jarrett (geb. 1945) Jasmine
2. 2
   Michael Wollny (geb. 1978) Nachtfahrten
3. 3
   Götz Alsmann Winterwunderwelt Vol. 2
4. 4
   Solveig Slettahjell & Knut Reiersrud Trail Of Souls
5. 5
   Brad Mehldau (geb. 1970) 10 Years Solo Live
6. 6
   Barbara Dennerlein (geb. 1964) Christmas Soul
7. 7
   Michael Wollny (geb. 1978) Weltentraum
8. 8
   Weather Report The Legendary Live Tapes: 1978 - 1981
9. 9
   Kamasi Washington (geb. 1981) The Epic
10. 10
    Lisa Bassenge (geb. 1974) Canyon Songs
11. Die kompletten Jazz-Charts

## Unser Jazz-Shop im Überblick

1. ### Jazz nach Medien

   - CD-Charts
   - SACD-Charts
   - Blu-ray-Charts
   - DVD-Charts
   Sonderangebote
   - Jazz-Sonderangebote

2. ### Audiophile Formate

   - Vinyl (200 g)
   - Blu-ray Disc
   - Super Audio CD

3. ### Vorschau – was erscheint wann

   - Jetzt vorbestellen
   - Nächste Woche
   - Laufender Monat
   - Nächster Monat
   - Wieder lieferbar

4. ### Schnäppchen

   - Jazz-CDs für EUR 5,99
   - Jazz-CDs für EUR 4,99
   - Alle Jazz-Schnäppchen auf einen Blick
   Radikal reduziert
   - Jazz – radikal reduziert

5. ### Beliebte Genres

   - Avantgarde
   - Big Band/Swing
   - Freejazz
   - Fusion
   - Modern Jazz
   - Piano Jazz
   - Ragtime/Chicago Style
   - Vocal Jazz

6. ### Labels

   - ACT
   - Blue Note
   - ECM
   - ENJA
   - Rhino
   - Verve

## Specials

1. ### Jetzt zum Sonderpreis

   - Sony Music Nice Price

2. ### Challenge Records

   - Gib dem Jazz eine Chance! Neues von Challenge
   - The Best Jazz Is Timeless Jazz Legacy

3. ### Sonderpreis-Aktionen

   - Collectors Mine: Not-Now-CDs

4. ### Empfehlungen von Labels

   - Jazzline – Legendäre Konzerte hervorragend restauriert
   - H'art: Domino Records

5. ### Specials

   - Exklusiv für jpc signierte CDs
   - T-Shirts und Merchandise
   - Papersleeve

© jpc-schallplatten Versandhandelsgesellschaft mbH